"""Shared test fixtures for NephroSim."""

import pytest
import numpy as np

import nephrosim  # noqa: F401


@pytest.fixture
def rng():
    return np.random.default_rng(42)


@pytest.fixture
def easy_patient():
    from nephrosim.models.patient import create_patient
    return create_patient("easy")


@pytest.fixture
def medium_patient():
    from nephrosim.models.patient import create_patient
    return create_patient("medium", np.random.default_rng(42))


@pytest.fixture
def hard_patient():
    from nephrosim.models.patient import create_patient
    return create_patient("hard", np.random.default_rng(42))
