"""NephroSim Gymnasium environments."""

from gymnasium.envs.registration import register


def register_envs() -> None:
    """Register all NephroSim environments with Gymnasium."""
    register(
        id="nephrosim/UreaClearing-v0",
        entry_point="nephrosim.envs.urea_clearing:UreaClearingEnv",
    )
    register(
        id="nephrosim/UltrafiltrationControl-v0",
        entry_point="nephrosim.envs.ultrafiltration_control:UltrafiltrationControlEnv",
    )
    register(
        id="nephrosim/PhosphateMgmt-v0",
        entry_point="nephrosim.envs.phosphate_mgmt:PhosphateMgmtEnv",
    )
    register(
        id="nephrosim/FullDialysisSession-v0",
        entry_point="nephrosim.envs.full_session:FullDialysisSessionEnv",
    )


__all__ = ["register_envs"]
